NgrokFlutterBindings class

Constructors

NgrokFlutterBindings(DynamicLibrary dynamicLibrary)
NgrokFlutterBindings.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ngrok_free_string(Pointer<Char> s) → void
ngrok_start_tunnel(Pointer<Char> authtoken, Pointer<Char> target_addr) Pointer<Char>
ngrok_stop_tunnel() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited